@@ -131,7 +131,7 @@ struct _GESAssetPrivate
   GList *proxies;
   GESAsset *proxy_target;
 
-  /* The error that accured when an asset has been initialized with error */
+  /* The error that occurred when an asset has been initialized with error */
   GError *error;
 };
 
@@ -145,7 +145,7 @@ typedef struct
 } GESAssetCacheEntry;
 
 /* Also protect all the entries in the cache */
-static GMutex asset_cache_lock;
+G_LOCK_DEFINE_STATIC (asset_cache_lock);
 /* We are mapping entries by types and ID, such as:
  *
  * {
@@ -169,8 +169,8 @@ static GMutex asset_cache_lock;
  * different extractable types.
  **/
 static GHashTable *type_entries_table = NULL;
-#define LOCK_CACHE   (g_mutex_lock (&asset_cache_lock))
-#define UNLOCK_CACHE (g_mutex_unlock (&asset_cache_lock))
+#define LOCK_CACHE   (G_LOCK (asset_cache_lock))
+#define UNLOCK_CACHE (G_UNLOCK (asset_cache_lock))
 
 static gchar *
 _check_and_update_parameters (GType * extractable_type, const gchar * id,
@@ -403,6 +403,9 @@ ges_asset_finalize (GObject * object)
   if (priv->error)
     g_error_free (priv->error);
 
+  if (priv->proxies)
+    g_list_free (priv->proxies);
+
   G_OBJECT_CLASS (ges_asset_parent_class)->finalize (object);
 }
 
@@ -483,6 +486,9 @@ _lookup_entry (GType extractable_type, const gchar * id)
 static void
 _free_entries (gpointer entry)
 {
+  GESAssetCacheEntry *data = (GESAssetCacheEntry *) entry;
+  if (data->asset)
+    gst_object_unref (data->asset);
   g_slice_free (GESAssetCacheEntry, entry);
 }
 
@@ -631,14 +637,20 @@ ges_asset_cache_put (GESAsset * asset, GTask * task)
 void
 ges_asset_cache_init (void)
 {
-  g_mutex_init (&asset_cache_lock);
   type_entries_table = g_hash_table_new_full (g_str_hash, g_str_equal,
-      NULL, (GDestroyNotify) g_hash_table_unref);
+      g_free, (GDestroyNotify) g_hash_table_unref);
 
   _init_formatter_assets ();
   _init_standard_transition_assets ();
 }
 
+void
+ges_asset_cache_deinit (void)
+{
+  g_hash_table_destroy (type_entries_table);
+  type_entries_table = NULL;
+}
+
 gboolean
 ges_asset_request_id_update (GESAsset * asset, gchar ** proposed_id,
     GError * error)
