@@ -139,6 +139,9 @@ track_disable_last_gap        (GESTrack *track, gboolean disabled);
 G_GNUC_INTERNAL void
 ges_asset_cache_init (void);
 
+G_GNUC_INTERNAL void
+ges_asset_cache_deinit (void);
+
 G_GNUC_INTERNAL void
 ges_asset_set_id (GESAsset *asset, const gchar *id);
 
@@ -164,6 +167,8 @@ ges_effect_assect_id_get_type_and_bindesc (const char    *id,
 
 G_GNUC_INTERNAL void _ges_uri_asset_cleanup (void);
 
+G_GNUC_INTERNAL gboolean _ges_uri_asset_ensure_setup (gpointer uriasset_class);
+
 /* GESExtractable internall methods
  *
  * FIXME Check if that should be public later
@@ -214,6 +219,7 @@ G_GNUC_INTERNAL  gchar * ges_project_try_updating_id              (GESProject *s
 G_GNUC_INTERNAL  void ges_project_add_loading_asset               (GESProject *project,
                                                                    GType extractable_type,
                                                                    const gchar *id);
+G_GNUC_INTERNAL  gchar* ges_uri_asset_try_update_id               (GError *error, GESAsset *wrong_asset);
 /************************************************
  *                                              *
  *   GESBaseXmlFormatter internal methods       *
@@ -288,7 +294,8 @@ G_GNUC_INTERNAL void ges_base_xml_formatter_add_source          (GESBaseXmlForma
 
 G_GNUC_INTERNAL void ges_base_xml_formatter_add_group           (GESBaseXmlFormatter *self,
                                                                  const gchar *name,
-                                                                 const gchar *properties);
+                                                                 const gchar *properties,
+                                                                 const gchar *metadatas);
 
 G_GNUC_INTERNAL void ges_base_xml_formatter_last_group_add_child(GESBaseXmlFormatter *self,
                                                                  const gchar * id,
