@@ -26,6 +26,9 @@
  * as priority. A GESTimelineElement can have a parent object which will be
  * responsible for controlling its timing properties.
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "ges-utils.h"
 #include "ges-timeline-element.h"
@@ -52,11 +55,6 @@ ges_extractable_interface_init (GESExtractableInterface * iface)
   iface->set_asset = extractable_set_asset;
 }
 
-G_DEFINE_ABSTRACT_TYPE_WITH_CODE (GESTimelineElement, ges_timeline_element,
-    G_TYPE_INITIALLY_UNOWNED,
-    G_IMPLEMENT_INTERFACE (GES_TYPE_EXTRACTABLE, ges_extractable_interface_init)
-    G_IMPLEMENT_INTERFACE (GES_TYPE_META_CONTAINER, NULL));
-
 enum
 {
   PROP_0,
@@ -107,6 +105,18 @@ typedef struct
   GESTimelineElement *self;
 } EmitDeepNotifyInIdleData;
 
+G_DEFINE_ABSTRACT_TYPE_WITH_CODE (GESTimelineElement, ges_timeline_element,
+    G_TYPE_INITIALLY_UNOWNED, G_ADD_PRIVATE (GESTimelineElement)
+    G_IMPLEMENT_INTERFACE (GES_TYPE_EXTRACTABLE, ges_extractable_interface_init)
+    G_IMPLEMENT_INTERFACE (GES_TYPE_META_CONTAINER, NULL));
+
+static void
+_set_child_property (GESTimelineElement * self G_GNUC_UNUSED, GObject * child,
+    GParamSpec * pspec, GValue * value)
+{
+  g_object_set_property (child, pspec->name, value);
+}
+
 static gboolean
 _lookup_child (GESTimelineElement * self, const gchar * prop_name,
     GObject ** child, GParamSpec ** pspec)
@@ -264,6 +274,8 @@ ges_timeline_element_dispose (GObject * object)
   }
 
   g_clear_object (&self->priv->copied_from);
+
+  G_OBJECT_CLASS (ges_timeline_element_parent_class)->dispose (object);
 }
 
 static void
@@ -290,8 +302,7 @@ _child_prop_handler_free (ChildPropHandler * handler)
 static void
 ges_timeline_element_init (GESTimelineElement * self)
 {
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-      GES_TYPE_TIMELINE_ELEMENT, GESTimelineElementPrivate);
+  self->priv = ges_timeline_element_get_instance_private (self);
 
   self->priv->serialize = TRUE;
 
@@ -306,8 +317,6 @@ ges_timeline_element_class_init (GESTimelineElementClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GESTimelineElementPrivate));
-
   object_class->get_property = _get_property;
   object_class->set_property = _set_property;
 
@@ -434,6 +443,7 @@ ges_timeline_element_class_init (GESTimelineElementClass * klass)
 
   klass->list_children_properties = default_list_children_properties;
   klass->lookup_child = _lookup_child;
+  klass->set_child_property = _set_child_property;
 }
 
 static void
@@ -671,14 +681,16 @@ ges_timeline_element_get_timeline (GESTimelineElement * self)
  *
  * Note that if the snapping-distance property of the timeline containing
  * @self is set, @self will properly snap to the edges around @start.
+ *
+ * Returns: %TRUE if @start could be set.
  */
-void
+gboolean
 ges_timeline_element_set_start (GESTimelineElement * self, GstClockTime start)
 {
   GESTimelineElementClass *klass;
   GESTimelineElement *toplevel_container, *parent;
 
-  g_return_if_fail (GES_IS_TIMELINE_ELEMENT (self));
+  g_return_val_if_fail (GES_IS_TIMELINE_ELEMENT (self), FALSE);
 
   klass = GES_TIMELINE_ELEMENT_GET_CLASS (self);
 
@@ -699,24 +711,26 @@ ges_timeline_element_set_start (GESTimelineElement * self, GstClockTime start)
         "container to have a negative start value");
 
     gst_object_unref (toplevel_container);
-    return;
+    return FALSE;
   }
 
   gst_object_unref (toplevel_container);
   if (klass->set_start) {
-    if (klass->set_start (self, start)) {
+    gboolean res = klass->set_start (self, start);
+    if (res) {
       self->start = start;
       g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_START]);
     }
 
     GST_DEBUG_OBJECT (self, "New start: %" GST_TIME_FORMAT,
         GST_TIME_ARGS (GES_TIMELINE_ELEMENT_START (self)));
-    return;
+    return res;
   }
 
   GST_WARNING_OBJECT (self, "No set_start virtual method implementation"
       " on class %s. Can not set start %" GST_TIME_FORMAT,
       G_OBJECT_CLASS_NAME (klass), GST_TIME_ARGS (start));
+  return FALSE;
 }
 
 /**
@@ -726,14 +740,16 @@ ges_timeline_element_set_start (GESTimelineElement * self, GstClockTime start)
  *
  * Set the in-point, that is the moment at which the @self will start
  * outputting data from its contents.
+ *
+ * Returns: %TRUE if @inpoint could be set.
  */
-void
+gboolean
 ges_timeline_element_set_inpoint (GESTimelineElement * self,
     GstClockTime inpoint)
 {
   GESTimelineElementClass *klass;
 
-  g_return_if_fail (GES_IS_TIMELINE_ELEMENT (self));
+  g_return_val_if_fail (GES_IS_TIMELINE_ELEMENT (self), FALSE);
 
   GST_DEBUG_OBJECT (self, "current inpoint: %" GST_TIME_FORMAT
       " new inpoint: %" GST_TIME_FORMAT, GST_TIME_ARGS (inpoint),
@@ -742,17 +758,20 @@ ges_timeline_element_set_inpoint (GESTimelineElement * self,
   klass = GES_TIMELINE_ELEMENT_GET_CLASS (self);
 
   if (klass->set_inpoint) {
-    if (klass->set_inpoint (self, inpoint)) {
+    gboolean res = klass->set_inpoint (self, inpoint);
+    if (res) {
       self->inpoint = inpoint;
       g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_INPOINT]);
     }
 
-    return;
+    return res;
   }
 
   GST_DEBUG_OBJECT (self, "No set_inpoint virtual method implementation"
       " on class %s. Can not set inpoint %" GST_TIME_FORMAT,
       G_OBJECT_CLASS_NAME (klass), GST_TIME_ARGS (inpoint));
+
+  return FALSE;
 }
 
 /**
@@ -761,14 +780,16 @@ ges_timeline_element_set_inpoint (GESTimelineElement * self,
  * @maxduration: the maximum duration in #GstClockTime
  *
  * Set the maximun duration of the object
+ *
+ * Returns: %TRUE if @maxduration could be set.
  */
-void
+gboolean
 ges_timeline_element_set_max_duration (GESTimelineElement * self,
     GstClockTime maxduration)
 {
   GESTimelineElementClass *klass;
 
-  g_return_if_fail (GES_IS_TIMELINE_ELEMENT (self));
+  g_return_val_if_fail (GES_IS_TIMELINE_ELEMENT (self), FALSE);
 
   klass = GES_TIMELINE_ELEMENT_GET_CLASS (self);
 
@@ -779,11 +800,12 @@ ges_timeline_element_set_max_duration (GESTimelineElement * self,
 
   if (klass->set_max_duration) {
     if (klass->set_max_duration (self, maxduration) == FALSE)
-      return;
+      return FALSE;
   }
 
   self->maxduration = maxduration;
   g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_MAX_DURATION]);
+  return TRUE;
 }
 
 /**
@@ -795,14 +817,16 @@ ges_timeline_element_set_max_duration (GESTimelineElement * self,
  *
  * Note that if the timeline snap-distance property of the timeline containing
  * @self is set, @self will properly snap to its neighboors.
+ *
+ * Returns: %TRUE if @duration could be set.
  */
-void
+gboolean
 ges_timeline_element_set_duration (GESTimelineElement * self,
     GstClockTime duration)
 {
   GESTimelineElementClass *klass;
 
-  g_return_if_fail (GES_IS_TIMELINE_ELEMENT (self));
+  g_return_val_if_fail (GES_IS_TIMELINE_ELEMENT (self), FALSE);
 
   klass = GES_TIMELINE_ELEMENT_GET_CLASS (self);
 
@@ -812,17 +836,19 @@ ges_timeline_element_set_duration (GESTimelineElement * self,
       GST_TIME_ARGS (duration));
 
   if (klass->set_duration) {
-    if (klass->set_duration (self, duration)) {
+    gboolean res = klass->set_duration (self, duration);
+    if (res) {
       self->duration = duration;
       g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_DURATION]);
     }
 
-    return;
+    return res;
   }
 
   GST_WARNING_OBJECT (self, "No set_duration virtual method implementation"
       " on class %s. Can not set duration %" GST_TIME_FORMAT,
       G_OBJECT_CLASS_NAME (klass), GST_TIME_ARGS (duration));
+  return FALSE;
 }
 
 /**
@@ -905,13 +931,15 @@ ges_timeline_element_get_priority (GESTimelineElement * self)
  * Deprecated: All priority management is done by GES itself now.
  * To set #GESEffect priorities #ges_clip_set_top_effect_index should
  * be used.
+ *
+ * Returns: %TRUE if @priority could be set.
  */
-void
+gboolean
 ges_timeline_element_set_priority (GESTimelineElement * self, guint32 priority)
 {
   GESTimelineElementClass *klass;
 
-  g_return_if_fail (GES_IS_TIMELINE_ELEMENT (self));
+  g_return_val_if_fail (GES_IS_TIMELINE_ELEMENT (self), FALSE);
 
   klass = GES_TIMELINE_ELEMENT_GET_CLASS (self);
 
@@ -919,16 +947,19 @@ ges_timeline_element_set_priority (GESTimelineElement * self, guint32 priority)
       self->priority, priority);
 
   if (klass->set_priority) {
-    if (klass->set_priority (self, priority)) {
+    gboolean res = klass->set_priority (self, priority);
+    if (res) {
       self->priority = priority;
       g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_PRIORITY]);
     }
-    return;
+
+    return res;
   }
 
   GST_WARNING_OBJECT (self, "No set_priority virtual method implementation"
       " on class %s. Can not set priority %d", G_OBJECT_CLASS_NAME (klass),
       priority);
+  return FALSE;
 }
 
 /**
@@ -1385,6 +1416,7 @@ ges_timeline_element_set_child_property_by_pspec (GESTimelineElement * self,
     GParamSpec * pspec, const GValue * value)
 {
   ChildPropHandler *handler;
+  GESTimelineElementClass *klass;
 
   g_return_if_fail (GES_IS_TRACK_ELEMENT (self));
 
@@ -1393,7 +1425,9 @@ ges_timeline_element_set_child_property_by_pspec (GESTimelineElement * self,
   if (!handler)
     goto not_found;
 
-  g_object_set_property (handler->child, pspec->name, (GValue *) value);
+  klass = GES_TIMELINE_ELEMENT_GET_CLASS (self);
+  g_assert (klass->set_child_property);
+  klass->set_child_property (self, handler->child, pspec, (GValue *) value);
 
   return;
 
@@ -1423,6 +1457,7 @@ ges_timeline_element_set_child_property (GESTimelineElement * self,
     const gchar * property_name, const GValue * value)
 {
   GParamSpec *pspec;
+  GESTimelineElementClass *klass;
   GObject *child;
 
   g_return_val_if_fail (GES_IS_TIMELINE_ELEMENT (self), FALSE);
@@ -1430,7 +1465,9 @@ ges_timeline_element_set_child_property (GESTimelineElement * self,
   if (!ges_timeline_element_lookup_child (self, property_name, &child, &pspec))
     goto not_found;
 
-  g_object_set_property (child, pspec->name, (GValue *) value);
+  klass = GES_TIMELINE_ELEMENT_GET_CLASS (self);
+  g_assert (klass->set_child_property);
+  klass->set_child_property (self, child, pspec, (GValue *) value);
 
   gst_object_unref (child);
   g_param_spec_unref (pspec);
