@@ -20,15 +20,16 @@
 
 /**
  * SECTION:gestitlesource
+ * @title: GESTitleSource
  * @short_description: render stand-alone text titles
  *
  * #GESTitleSource is a GESTimelineElement that implements the notion
  * of titles in GES.
  *
- * <refsect1 id="GESTileSource.children_properties" role="properties">
- * <title role="children_properties.title">Children Properties</title>
- * <para>You can use the following children properties through the
- * #ges_track_element_set_child_property and alike set of methods:</para>
+ * ## Children Properties
+ *
+ * You can use the following children properties through the
+ * #ges_track_element_set_child_property and alike set of methods:
  * <informaltable frame="none">
  * <tgroup cols="3">
  * <colspec colname="properties_type" colwidth="150px"/>
@@ -85,8 +86,10 @@
  * </tbody>
  * </tgroup>
  * </informaltable>
- * </refsect1>
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "ges-internal.h"
 #include "ges-track-element.h"
@@ -96,8 +99,6 @@
 #define DEFAULT_TEXT ""
 #define DEFAULT_FONT_DESC "Serif 36"
 
-G_DEFINE_TYPE (GESTitleSource, ges_title_source, GES_TYPE_VIDEO_SOURCE);
-
 struct _GESTitleSourcePrivate
 {
   gchar *text;
@@ -112,6 +113,9 @@ struct _GESTitleSourcePrivate
   GstElement *background_el;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (GESTitleSource, ges_title_source,
+    GES_TYPE_VIDEO_SOURCE);
+
 enum
 {
   PROP_0,
@@ -159,8 +163,6 @@ ges_title_source_class_init (GESTitleSourceClass * klass)
   GESTimelineElementClass *timeline_element_class =
       GES_TIMELINE_ELEMENT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GESTitleSourcePrivate));
-
   object_class->get_property = ges_title_source_get_property;
   object_class->set_property = ges_title_source_set_property;
   object_class->dispose = ges_title_source_dispose;
@@ -174,8 +176,7 @@ ges_title_source_class_init (GESTitleSourceClass * klass)
 static void
 ges_title_source_init (GESTitleSource * self)
 {
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-      GES_TYPE_TITLE_SOURCE, GESTitleSourcePrivate);
+  self->priv = ges_title_source_get_instance_private (self);
 
   self->priv->text = g_strdup (DEFAULT_TEXT);
   self->priv->font_desc = g_strdup (DEFAULT_FONT_DESC);
