@@ -26,7 +26,7 @@
  * The #GESUriClipAsset is a special #GESAsset that lets you handle
  * the media file to use inside the GStreamer Editing Services. It has APIs that
  * let you get information about the medias. Also, the tags found in the media file are
- * set as Metadatas of the Asser.
+ * set as Metadata of the Asset.
  */
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -43,7 +43,6 @@
 static GHashTable *parent_newparent_table = NULL;
 
 static GstDiscoverer *discoverer = NULL;
-static GstDiscoverer *sync_discoverer = NULL;
 
 static void
 initable_iface_init (GInitableIface * initable_iface)
@@ -75,6 +74,13 @@ struct _GESUriClipAssetPrivate
   GList *asset_trackfilesources;
 };
 
+typedef struct
+{
+  GMainLoop *ml;
+  GESAsset *asset;
+  GError *error;
+} RequestSyncData;
+
 struct _GESUriSourceAssetPrivate
 {
   GstDiscovererStreamInfo *sinfo;
@@ -188,21 +194,38 @@ _asset_proxied (GESAsset * self, const gchar * new_uri)
   gst_object_unref (new_file);
 }
 
+static void
+ges_uri_clip_asset_dispose (GObject * object)
+{
+  GESUriClipAsset *self = GES_URI_CLIP_ASSET (object);
+  GESUriClipAssetPrivate *prif = self->priv;
+
+  if (prif->asset_trackfilesources) {
+    g_list_free_full (prif->asset_trackfilesources,
+        (GDestroyNotify) gst_object_unref);
+    prif->asset_trackfilesources = NULL;
+  }
+
+  gst_clear_object (&prif->info);
+
+  G_OBJECT_CLASS (ges_uri_clip_asset_parent_class)->dispose (object);
+}
+
 static void
 ges_uri_clip_asset_class_init (GESUriClipAssetClass * klass)
 {
-  GError *err;
-  GstClockTime timeout;
-  const gchar *timeout_str;
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->get_property = ges_uri_clip_asset_get_property;
   object_class->set_property = ges_uri_clip_asset_set_property;
+  object_class->dispose = ges_uri_clip_asset_dispose;
 
   GES_ASSET_CLASS (klass)->start_loading = _start_loading;
   GES_ASSET_CLASS (klass)->request_id_update = _request_id_update;
   GES_ASSET_CLASS (klass)->inform_proxy = _asset_proxied;
 
+  klass->discovered = discoverer_discovered_cb;
+
 
   /**
    * GESUriClipAsset:duration:
@@ -215,59 +238,7 @@ ges_uri_clip_asset_class_init (GESUriClipAssetClass * klass)
   g_object_class_install_property (object_class, PROP_DURATION,
       properties[PROP_DURATION]);
 
-  timeout = DEFAULT_DISCOVERY_TIMEOUT;
-  errno = 0;
-  timeout_str = g_getenv ("GES_DISCOVERY_TIMEOUT");
-  if (timeout_str)
-    timeout = g_ascii_strtod (timeout_str, NULL) * GST_SECOND;
-  else
-    errno = 10;
-
-  if (errno)
-    timeout = DEFAULT_DISCOVERY_TIMEOUT;
-
-  if (!discoverer) {
-    discoverer = gst_discoverer_new (timeout, &err);
-    if (!discoverer) {
-      GST_ERROR ("Could not create discoverer: %s", err->message);
-      g_error_free (err);
-      return;
-    }
-  }
-
-  /* The class structure keeps weak pointers on the discoverers so they
-   * can be properly cleaned up in _ges_uri_asset_cleanup(). */
-  if (!klass->discoverer) {
-    klass->discoverer = discoverer;
-    g_object_add_weak_pointer (G_OBJECT (discoverer),
-        (gpointer *) & klass->discoverer);
-  }
-
-  if (!sync_discoverer) {
-    sync_discoverer = gst_discoverer_new (timeout, &err);
-
-    if (!sync_discoverer) {
-      GST_ERROR ("Could not create discoverer: %s", err->message);
-      g_error_free (err);
-      return;
-    }
-  }
-
-  if (!klass->sync_discoverer) {
-    klass->sync_discoverer = sync_discoverer;
-    g_object_add_weak_pointer (G_OBJECT (sync_discoverer),
-        (gpointer *) & klass->sync_discoverer);
-  }
-
-  g_signal_connect (klass->discoverer, "discovered",
-      G_CALLBACK (discoverer_discovered_cb), NULL);
-
-  /* We just start the discoverer and let it live */
-  gst_discoverer_start (klass->discoverer);
-  if (parent_newparent_table == NULL) {
-    parent_newparent_table = g_hash_table_new_full (g_file_hash,
-        (GEqualFunc) g_file_equal, gst_object_unref, gst_object_unref);
-  }
+  _ges_uri_asset_ensure_setup (klass);
 }
 
 static void
@@ -314,7 +285,7 @@ _create_uri_source_asset (GESUriClipAsset * asset,
       (tck_filesource_asset), type);
 
   priv->asset_trackfilesources = g_list_append (priv->asset_trackfilesources,
-      gst_object_ref (tck_filesource_asset));
+      tck_filesource_asset);
 }
 
 static void
@@ -441,6 +412,26 @@ discoverer_discovered_cb (GstDiscoverer * discoverer,
     g_error_free (error);
 }
 
+static void
+asset_ready_cb (GESAsset * source, GAsyncResult * res, RequestSyncData * data)
+{
+  data->asset = ges_asset_request_finish (res, &data->error);
+
+  if (data->error) {
+    gchar *possible_uri = ges_uri_asset_try_update_id (data->error, source);
+
+    if (possible_uri) {
+      g_clear_error (&data->error);
+      ges_asset_request_async (GES_TYPE_URI_CLIP, possible_uri, NULL,
+          (GAsyncReadyCallback) asset_ready_cb, data);
+      g_free (possible_uri);
+
+      return;
+    }
+  }
+  g_main_loop_quit (data->ml);
+}
+
 /* API implementation */
 /**
  * ges_uri_clip_asset_get_info:
@@ -509,7 +500,7 @@ ges_uri_clip_asset_is_image (GESUriClipAsset * self)
  *   GError *error = NULL;
  *   GESUriClipAsset *filesource_asset;
  *
- *   filesource_asset = GES_URI_CLIP_ASSET (ges_asset_request_finish (res, &error));
+ *   filesource_asset = ges_uri_clip_asset_finish (res, &error);
  *   if (filesource_asset) {
  *    g_print ("The file: %s is usable as a FileSource, it is%s an image and lasts %" GST_TIME_FORMAT,
  *        ges_asset_get_id (GES_ASSET (filesource_asset))
@@ -535,26 +526,48 @@ ges_uri_clip_asset_new (const gchar * uri, GCancellable * cancellable,
       callback, user_data);
 }
 
+/**
+ * ges_uri_clip_asset_finish:
+ * @res: The #GAsyncResult from which to get the newly created #GESUriClipAsset
+ * @error: An error to be set in case something wrong happens or %NULL
+ *
+ * Finalize the request of an async #GESUriClipAsset
+ *
+ * Returns: (transfer full): The #GESUriClipAsset previously requested
+ */
+GESUriClipAsset *
+ges_uri_clip_asset_finish (GAsyncResult * res, GError ** error)
+{
+  GESAsset *asset;
+
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (res), NULL);
+
+  asset = ges_asset_request_finish (res, error);
+  if (asset != NULL) {
+    return GES_URI_CLIP_ASSET (asset);
+  }
+
+  return NULL;
+}
+
 /**
  * ges_uri_clip_asset_request_sync:
  * @uri: The URI of the file for which to create a #GESUriClipAsset.
  * You can also use multi file uris for #GESMultiFileSource.
- * @error: (allow-none): An error to be set in case something wrong happens or %NULL
+ * @error: An error to be set in case something wrong happens or %NULL
  *
  * Creates a #GESUriClipAsset for @uri syncronously. You should avoid
  * to use it in application, and rather create #GESUriClipAsset asynchronously
  *
- * Returns: (transfer none) (nullable): A reference to the requested asset or
- * %NULL if an error happened
+ * Returns: (transfer full): A reference to the requested asset or %NULL if
+ * an error happened
  */
 GESUriClipAsset *
 ges_uri_clip_asset_request_sync (const gchar * uri, GError ** error)
 {
   GError *lerror = NULL;
-  GstDiscovererInfo *info;
-  GstDiscoverer *discoverer;
   GESUriClipAsset *asset;
-  gchar *first_file, *first_file_uri;
+  RequestSyncData data = { 0, };
 
   asset = GES_URI_CLIP_ASSET (ges_asset_request (GES_TYPE_URI_CLIP, uri,
           &lerror));
@@ -562,59 +575,21 @@ ges_uri_clip_asset_request_sync (const gchar * uri, GError ** error)
   if (asset)
     return asset;
 
-  if (lerror && lerror->domain == GES_ERROR &&
-      lerror->code == GES_ERROR_ASSET_WRONG_ID) {
-    g_propagate_error (error, lerror);
+  data.ml = g_main_loop_new (NULL, TRUE);
+  ges_asset_request_async (GES_TYPE_URI_CLIP, uri, NULL,
+      (GAsyncReadyCallback) asset_ready_cb, &data);
+  g_main_loop_run (data.ml);
+  g_main_loop_unref (data.ml);
+
+  if (data.error) {
+    GST_ERROR ("Got an error requesting asset: %s", data.error->message);
+    if (error != NULL)
+      g_propagate_error (error, data.error);
 
     return NULL;
   }
 
-  asset = g_object_new (GES_TYPE_URI_CLIP_ASSET, "id", uri,
-      "extractable-type", GES_TYPE_URI_CLIP, NULL);
-  discoverer = GES_URI_CLIP_ASSET_GET_CLASS (asset)->sync_discoverer;
-
-  if (g_str_has_prefix (uri, GES_MULTI_FILE_URI_PREFIX)) {
-    GESMultiFileURI *uri_data;
-
-    uri_data = ges_multi_file_uri_new (uri);
-    first_file = g_strdup_printf (uri_data->location, uri_data->start);
-    first_file_uri = gst_filename_to_uri (first_file, &lerror);
-    info = gst_discoverer_discover_uri (discoverer, first_file_uri, &lerror);
-    GST_DEBUG ("Got multifile uri. Discovering first file %s", first_file_uri);
-    g_free (uri_data);
-    g_free (first_file_uri);
-    g_free (first_file);
-  } else {
-    info = gst_discoverer_discover_uri (discoverer, uri, &lerror);
-  }
-
-  /* We might get a discoverer info but it might have a non-OK result. We
-   * should consider that an error */
-  if (!lerror && info
-      && gst_discoverer_info_get_result (info) != GST_DISCOVERER_OK) {
-    lerror =
-        g_error_new (GST_RESOURCE_ERROR, GST_RESOURCE_ERROR_FAILED,
-        "Stream %s discovering failed (error code: %d)", uri,
-        gst_discoverer_info_get_result (info));
-  }
-
-  _set_meta_file_size (uri, asset);
-
-  ges_asset_cache_put (gst_object_ref (asset), NULL);
-  ges_uri_clip_asset_set_info (asset, info);
-  ges_asset_cache_set_loaded (GES_TYPE_URI_CLIP, uri, lerror);
-
-  if (info == NULL || lerror != NULL) {
-    gst_object_unref (asset);
-    if (info)
-      gst_discoverer_info_unref (info);
-    if (lerror)
-      g_propagate_error (error, lerror);
-
-    return NULL;
-  }
-
-  return asset;
+  return GES_URI_CLIP_ASSET (data.asset);
 }
 
 /**
@@ -631,7 +606,6 @@ ges_uri_clip_asset_class_set_timeout (GESUriClipAssetClass * klass,
   g_return_if_fail (GES_IS_URI_CLIP_ASSET_CLASS (klass));
 
   g_object_set (klass->discoverer, "timeout", timeout, NULL);
-  g_object_set (klass->sync_discoverer, "timeout", timeout, NULL);
 }
 
 /**
@@ -706,9 +680,24 @@ _extract (GESAsset * asset, GError ** error)
   return GES_EXTRACTABLE (trackelement);
 }
 
+static void
+ges_uri_source_asset_dispose (GObject * object)
+{
+  GESUriSourceAsset *self = GES_URI_SOURCE_ASSET (object);
+  GESUriSourceAssetPrivate *priv = self->priv;
+
+  gst_clear_object (&priv->sinfo);
+
+  G_OBJECT_CLASS (ges_uri_source_asset_parent_class)->dispose (object);
+}
+
 static void
 ges_uri_source_asset_class_init (GESUriSourceAssetClass * klass)
 {
+  GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+  object_class->dispose = ges_uri_source_asset_dispose;
+
   GES_ASSET_CLASS (klass)->extract = _extract;
 }
 
@@ -768,5 +757,63 @@ void
 _ges_uri_asset_cleanup (void)
 {
   g_clear_object (&discoverer);
-  g_clear_object (&sync_discoverer);
+  if (parent_newparent_table) {
+    g_hash_table_destroy (parent_newparent_table);
+    parent_newparent_table = NULL;
+  }
+}
+
+gboolean
+_ges_uri_asset_ensure_setup (gpointer uriasset_class)
+{
+  GESUriClipAssetClass *klass;
+  GError *err;
+  GstClockTime timeout;
+  const gchar *timeout_str;
+
+  g_return_val_if_fail (GES_IS_URI_CLIP_ASSET_CLASS (uriasset_class), FALSE);
+
+  klass = GES_URI_CLIP_ASSET_CLASS (uriasset_class);
+
+  timeout = DEFAULT_DISCOVERY_TIMEOUT;
+  errno = 0;
+  timeout_str = g_getenv ("GES_DISCOVERY_TIMEOUT");
+  if (timeout_str)
+    timeout = g_ascii_strtod (timeout_str, NULL) * GST_SECOND;
+  else
+    errno = 10;
+
+  if (errno)
+    timeout = DEFAULT_DISCOVERY_TIMEOUT;
+
+  if (!discoverer) {
+    discoverer = gst_discoverer_new (timeout, &err);
+    if (!discoverer) {
+      GST_ERROR ("Could not create discoverer: %s", err->message);
+      g_error_free (err);
+      return FALSE;
+    }
+  }
+
+  /* The class structure keeps weak pointers on the discoverers so they
+   * can be properly cleaned up in _ges_uri_asset_cleanup(). */
+  if (!klass->discoverer) {
+    klass->discoverer = klass->sync_discoverer = discoverer;
+    g_object_add_weak_pointer (G_OBJECT (discoverer),
+        (gpointer *) & klass->discoverer);
+    g_object_add_weak_pointer (G_OBJECT (discoverer),
+        (gpointer *) & klass->sync_discoverer);
+
+    g_signal_connect (klass->discoverer, "discovered",
+        G_CALLBACK (klass->discovered), NULL);
+  }
+
+  /* We just start the discoverer and let it live */
+  gst_discoverer_start (klass->discoverer);
+  if (parent_newparent_table == NULL) {
+    parent_newparent_table = g_hash_table_new_full (g_file_hash,
+        (GEqualFunc) g_file_equal, g_object_unref, g_object_unref);
+  }
+
+  return TRUE;
 }
