@@ -27,29 +27,125 @@
 static GMainLoop *mainloop;
 
 static void
-source_asset_created (GObject * source, GAsyncResult * res, gpointer udata)
+source_asset_created (GObject * source, GAsyncResult * res,
+    gpointer expected_ok)
 {
   GError *error = NULL;
 
   GESAsset *a = ges_asset_request_finish (res, &error);
 
-  fail_unless (a == NULL);
-  assert_equals_int (error->domain, GST_RESOURCE_ERROR);
+  if (GPOINTER_TO_INT (expected_ok)) {
+    fail_unless (a != NULL);
+    fail_unless (error == NULL);
+  } else {
+    fail_unless (a == NULL);
+    assert_equals_int (error->domain, GST_RESOURCE_ERROR);
+  }
 
+  g_clear_error (&error);
   g_main_loop_quit (mainloop);
 }
 
 GST_START_TEST (test_basic)
 {
-  gst_init (NULL, NULL);
   ges_init ();
 
   mainloop = g_main_loop_new (NULL, FALSE);
   ges_asset_request_async (GES_TYPE_URI_CLIP,
-      "file:///this/is/not/for/real", NULL, source_asset_created, NULL);
+      "file:///this/is/not/for/real", NULL, source_asset_created,
+      GINT_TO_POINTER (FALSE));
 
   g_main_loop_run (mainloop);
   g_main_loop_unref (mainloop);
+  ges_deinit ();
+}
+
+GST_END_TEST;
+
+typedef struct _CustomContextData
+{
+  GMutex lock;
+  GCond cond;
+  gboolean finish;
+  gboolean expected_ok;
+  gchar *uri;
+} CustomContextData;
+
+static gpointer
+custom_context_thread_func (CustomContextData * data)
+{
+  GMainContext *context;
+
+  context = g_main_context_new ();
+  mainloop = g_main_loop_new (context, FALSE);
+
+  g_main_context_push_thread_default (context);
+
+  /* To use custom context, we need to call ges_init() in the thread */
+  fail_unless (ges_init ());
+
+  ges_asset_request_async (GES_TYPE_URI_CLIP,
+      data->uri, NULL, source_asset_created,
+      GINT_TO_POINTER (data->expected_ok));
+  g_main_loop_run (mainloop);
+
+  g_main_context_pop_thread_default (context);
+  ges_deinit ();
+  g_main_context_unref (context);
+  g_main_loop_unref (mainloop);
+
+  data->finish = TRUE;
+  g_cond_signal (&data->cond);
+
+  return NULL;
+}
+
+GST_START_TEST (test_custom_context)
+{
+  GThread *thread;
+  CustomContextData data;
+
+  mainloop = NULL;
+
+  g_mutex_init (&data.lock);
+  g_cond_init (&data.cond);
+  /* ensure default context here, but we will not use the default context */
+  g_main_context_default ();
+
+  /* first run with invalid uri */
+  data.finish = FALSE;
+  data.expected_ok = FALSE;
+  data.uri = g_strdup ("file:///this/is/not/for/real");
+
+  thread = g_thread_new ("test-custom-context-thread",
+      (GThreadFunc) custom_context_thread_func, &data);
+
+  g_mutex_lock (&data.lock);
+  while (data.finish)
+    g_cond_wait (&data.cond, &data.lock);
+  g_mutex_unlock (&data.lock);
+
+  g_thread_join (thread);
+  g_free (data.uri);
+
+  /* second run with valid uri */
+  data.finish = FALSE;
+  data.expected_ok = TRUE;
+  data.uri = ges_test_file_uri ("audio_video.ogg");
+
+  thread = g_thread_new ("test-custom-context-thread",
+      (GThreadFunc) custom_context_thread_func, &data);
+
+  g_mutex_lock (&data.lock);
+  while (data.finish)
+    g_cond_wait (&data.cond, &data.lock);
+  g_mutex_unlock (&data.lock);
+
+  g_thread_join (thread);
+  g_free (data.uri);
+
+  g_mutex_clear (&data.lock);
+  g_cond_clear (&data.cond);
 }
 
 GST_END_TEST;
@@ -60,7 +156,6 @@ GST_START_TEST (test_transition_change_asset)
   GESAsset *a;
   GESExtractable *extractable;
 
-  gst_init (NULL, NULL);
   ges_init ();
 
   a = ges_asset_request (GES_TYPE_TRANSITION_CLIP, "box-wipe-lc", NULL);
@@ -90,9 +185,12 @@ GST_START_TEST (test_transition_change_asset)
   /* Now try to set the a and see if the vtype is properly updated */
   a = ges_asset_request (GES_TYPE_TRANSITION_CLIP, "box-wipe-lc", NULL);
   ges_extractable_set_asset (extractable, a);
+  gst_object_unref (a);
+
   fail_unless_equals_int (GES_TRANSITION_CLIP (extractable)->vtype, 26);
 
   gst_object_unref (extractable);
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -101,16 +199,20 @@ GST_START_TEST (test_uri_clip_change_asset)
 {
   GESAsset *asset, *asset1;
   GESExtractable *extractable;
-  GESLayer *layer = ges_layer_new ();
-  gchar *uri = ges_test_file_uri ("audio_video.ogg");
-  gchar *uri1 = ges_test_file_uri ("audio_only.ogg");
-  GESTimeline *timeline = ges_timeline_new_audio_video ();
+  GESLayer *layer;
+  gchar *uri;
+  gchar *uri1;
+  GESTimeline *timeline;
+
+  ges_init ();
+
+  layer = ges_layer_new ();
+  uri = ges_test_file_uri ("audio_video.ogg");
+  uri1 = ges_test_file_uri ("audio_only.ogg");
+  timeline = ges_timeline_new_audio_video ();
 
   ges_timeline_add_layer (timeline, layer);
 
-  gst_init (NULL, NULL);
-  ges_init ();
-
   asset = GES_ASSET (ges_uri_clip_asset_request_sync (uri, NULL));
 
   fail_unless (GES_IS_ASSET (asset));
@@ -133,6 +235,8 @@ GST_START_TEST (test_uri_clip_change_asset)
 
   g_free (uri);
   g_free (uri1);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -141,6 +245,9 @@ GST_START_TEST (test_list_asset)
 {
   GList *assets;
   GEnumClass *enum_class;
+
+  ges_init ();
+
   enum_class = g_type_class_peek (GES_VIDEO_STANDARD_TRANSITION_TYPE_TYPE);
 
   fail_unless (ges_init ());
@@ -150,6 +257,8 @@ GST_START_TEST (test_list_asset)
   /* note: we do not have a a for value=0 "Transition not set" */
   assert_equals_int (g_list_length (assets), enum_class->n_values - 1);
   g_list_free (assets);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -193,6 +302,8 @@ GST_START_TEST (test_proxy_asset)
 
   gst_object_unref (identity);
   gst_object_unref (nothing_at_all);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -203,18 +314,13 @@ ges_suite (void)
   Suite *s = suite_create ("ges");
   TCase *tc_chain = tcase_create ("a");
 
-  if (atexit (ges_deinit) != 0) {
-    GST_ERROR ("failed to set ges_deinit as exit function");
-  }
-
   suite_add_tcase (s, tc_chain);
-  ges_init ();
 
-  /* Must be first until we implement deinit */
-  tcase_add_test (tc_chain, test_list_asset);
   tcase_add_test (tc_chain, test_basic);
+  tcase_add_test (tc_chain, test_custom_context);
   tcase_add_test (tc_chain, test_transition_change_asset);
   tcase_add_test (tc_chain, test_uri_clip_change_asset);
+  tcase_add_test (tc_chain, test_list_asset);
   tcase_add_test (tc_chain, test_proxy_asset);
 
   return s;
