@@ -139,6 +139,8 @@ GST_START_TEST (test_ges_scenario)
   /* Finally clean up our object */
   ASSERT_OBJECT_REFCOUNT (timeline, "timeline", 1);
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -253,6 +255,8 @@ GST_START_TEST (test_ges_timeline_add_layer)
 
   /* theoretically this is all we need to do to ensure cleanup */
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -267,6 +271,8 @@ GST_START_TEST (test_ges_timeline_add_layer_first)
   GESTestClip *s1, *s2, *s3;
   GList *trackelements, *tmp, *layers;
 
+  ges_init ();
+
   /* Timeline and 1 Layer */
   GST_DEBUG ("Create a timeline");
   timeline = ges_timeline_new ();
@@ -354,6 +360,8 @@ GST_START_TEST (test_ges_timeline_add_layer_first)
 
   /* theoretically this is all we need to do to ensure cleanup */
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -367,6 +375,8 @@ GST_START_TEST (test_ges_timeline_remove_track)
   GESTrackElement *t1, *t2, *t3;
   GList *trackelements, *tmp, *layers;
 
+  ges_init ();
+
   /* Timeline and 1 Layer */
   GST_DEBUG ("Create a timeline");
   timeline = ges_timeline_new ();
@@ -485,10 +495,12 @@ GST_START_TEST (test_ges_timeline_remove_track)
   ASSERT_OBJECT_REFCOUNT (timeline, "1 for the us", 1);
   tmp = ges_layer_get_clips (layer);
   assert_equals_int (g_list_length (tmp), 3);
-  g_list_foreach (tmp, (GFunc) gst_object_unref, NULL);
+  g_list_free_full (tmp, (GDestroyNotify) gst_object_unref);
 
   gst_check_objects_destroyed_on_unref (G_OBJECT (timeline),
       G_OBJECT (layer), t1, t2, t3, NULL);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -525,6 +537,8 @@ GST_START_TEST (test_ges_timeline_multiple_tracks)
   GList *trackelements, *tmp, *layers;
   SelectTracksData st_data = { &s1, &s2, &s3, &track1, &track2 };
 
+  ges_init ();
+
   /* Timeline and 1 Layer */
   GST_DEBUG ("Create a timeline");
   timeline = ges_timeline_new ();
@@ -655,6 +669,8 @@ GST_START_TEST (test_ges_timeline_multiple_tracks)
   gst_object_unref (t3);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -667,6 +683,8 @@ GST_START_TEST (test_ges_pipeline_change_state)
   GESTimeline *timeline;
   GESPipeline *pipeline;
 
+  ges_init ();
+
   layer = ges_layer_new ();
   timeline = ges_timeline_new_audio_video ();
   fail_unless (ges_timeline_add_layer (timeline, layer));
@@ -687,6 +705,8 @@ GST_START_TEST (test_ges_pipeline_change_state)
       GST_STATE_CHANGE_SUCCESS);
 
   gst_object_unref (pipeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -698,6 +718,8 @@ GST_START_TEST (test_ges_timeline_element_name)
   GESTimeline *timeline;
   GESLayer *layer;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   fail_unless (ges_timeline_add_layer (timeline, layer));
@@ -749,6 +771,8 @@ GST_START_TEST (test_ges_timeline_element_name)
   gst_object_unref (clip4);
   gst_object_unref (clip5);
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -759,12 +783,6 @@ ges_suite (void)
   Suite *s = suite_create ("ges-basic");
   TCase *tc_chain = tcase_create ("basic");
 
-  ges_init ();
-
-  if (atexit (ges_deinit) != 0) {
-    GST_ERROR ("failed to set ges_deinit as exit function");
-  }
-
   suite_add_tcase (s, tc_chain);
 
   tcase_add_test (tc_chain, test_ges_scenario);
