@@ -30,6 +30,8 @@ GST_START_TEST (test_object_properties)
   GESLayer *layer;
   GESTrackElement *trackelement;
 
+  ges_init ();
+
   track = GES_TRACK (ges_video_track_new ());
   fail_unless (track != NULL);
 
@@ -97,6 +99,8 @@ GST_START_TEST (test_object_properties)
       GES_TIMELINE_ELEMENT (trackelement));
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -114,6 +118,8 @@ GST_START_TEST (test_split_direct_bindings)
 
   GESTrackElement *element;
 
+  ges_init ();
+
   fail_unless ((timeline = ges_timeline_new ()));
   fail_unless ((layer = ges_layer_new ()));
   fail_unless (ges_timeline_add_track (timeline,
@@ -181,6 +187,8 @@ GST_START_TEST (test_split_direct_bindings)
 
   CHECK_OBJECT_PROPS (clip, 0 * GST_SECOND, 10 * GST_SECOND, 5 * GST_SECOND);
   check_layer (clip, 0);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -198,6 +206,8 @@ GST_START_TEST (test_split_direct_absolute_bindings)
 
   GESTrackElement *element;
 
+  ges_init ();
+
   fail_unless ((timeline = ges_timeline_new ()));
   fail_unless ((layer = ges_layer_new ()));
   fail_unless (ges_timeline_add_track (timeline,
@@ -265,6 +275,8 @@ GST_START_TEST (test_split_direct_absolute_bindings)
 
   CHECK_OBJECT_PROPS (clip, 0 * GST_SECOND, 10 * GST_SECOND, 5 * GST_SECOND);
   check_layer (clip, 0);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -278,6 +290,8 @@ GST_START_TEST (test_split_object)
   GList *splittrackelements;
   GESTrackElement *trackelement, *splittrackelement;
 
+  ges_init ();
+
   layer = ges_layer_new ();
   fail_unless (layer != NULL);
   timeline = ges_timeline_new_audio_video ();
@@ -355,6 +369,8 @@ GST_START_TEST (test_split_object)
 
   check_destroyed (G_OBJECT (timeline), G_OBJECT (splitclip), clip,
       splittrackelement, NULL);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -369,6 +385,8 @@ GST_START_TEST (test_clip_group_ungroup)
   GESContainer *regrouped_clip;
   GESTrack *audio_track, *video_track;
 
+  ges_init ();
+
   timeline = ges_timeline_new ();
   layer = ges_layer_new ();
   audio_track = GES_TRACK (ges_audio_track_new ());
@@ -479,6 +497,8 @@ GST_START_TEST (test_clip_group_ungroup)
   g_list_free_full (tmp, gst_object_unref);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -499,6 +519,8 @@ GST_START_TEST (test_clip_refcount_remove_child)
   gboolean called;
   GESTrackElement *effect;
 
+  ges_init ();
+
   clip = GES_CLIP (ges_test_clip_new ());
   track = GES_TRACK (ges_audio_track_new ());
   effect = GES_TRACK_ELEMENT (ges_effect_new ("identity"));
@@ -519,6 +541,8 @@ GST_START_TEST (test_clip_refcount_remove_child)
 
   check_destroyed (G_OBJECT (track), NULL, NULL);
   check_destroyed (G_OBJECT (clip), NULL, NULL);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -532,6 +556,8 @@ GST_START_TEST (test_clip_find_track_element)
 
   GESTrackElement *effect, *effect1, *effect2, *foundelem;
 
+  ges_init ();
+
   clip = GES_CLIP (ges_test_clip_new ());
   track = GES_TRACK (ges_audio_track_new ());
   track1 = GES_TRACK (ges_audio_track_new ());
@@ -583,6 +609,8 @@ GST_START_TEST (test_clip_find_track_element)
   g_list_free_full (foundelements, gst_object_unref);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -596,6 +624,8 @@ GST_START_TEST (test_effects_priorities)
 
   GESTrackElement *effect, *effect1, *effect2;
 
+  ges_init ();
+
   clip = GES_CLIP (ges_test_clip_new ());
   audio_track = GES_TRACK (ges_audio_track_new ());
   video_track = GES_TRACK (ges_video_track_new ());
@@ -673,6 +703,8 @@ GST_START_TEST (test_effects_priorities)
       _PRIORITY (effect2));
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -683,12 +715,6 @@ ges_suite (void)
   Suite *s = suite_create ("ges-clip");
   TCase *tc_chain = tcase_create ("clip");
 
-  ges_init ();
-
-  if (atexit (ges_deinit) != 0) {
-    GST_ERROR ("failed to set ges_deinit as exit function");
-  }
-
   suite_add_tcase (s, tc_chain);
 
   tcase_add_test (tc_chain, test_object_properties);
