@@ -31,6 +31,8 @@ GST_START_TEST (test_layer_properties)
   GESTrackElement *trackelement;
   GESClip *clip;
 
+  ges_init ();
+
   /* Timeline and 1 Layer */
   timeline = ges_timeline_new ();
 
@@ -103,6 +105,8 @@ GST_START_TEST (test_layer_properties)
   fail_unless (ges_timeline_remove_track (timeline, track));
   fail_unless (ges_timeline_remove_layer (timeline, layer));
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -118,6 +122,8 @@ GST_START_TEST (test_layer_priorities)
   guint prio1, prio2, prio3;
   GList *objs;
 
+  ges_init ();
+
   /* Timeline and 3 Layer */
   timeline = ges_timeline_new ();
   fail_unless ((layer1 = ges_timeline_append_layer (timeline)));
@@ -228,6 +234,8 @@ GST_START_TEST (test_layer_priorities)
   gst_object_unref (trackelement2);
   gst_object_unref (trackelement3);
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -238,8 +246,11 @@ GST_START_TEST (test_timeline_auto_transition)
   GESTimeline *timeline;
   GESLayer *layer, *layer1, *layer2;
 
+  ges_init ();
+
   asset = ges_asset_request (GES_TYPE_TEST_CLIP, NULL, NULL);
   fail_unless (GES_IS_ASSET (asset));
+  gst_object_unref (asset);
 
   GST_DEBUG ("Create timeline");
   timeline = ges_timeline_new_audio_video ();
@@ -287,6 +298,8 @@ GST_START_TEST (test_timeline_auto_transition)
   fail_unless (ges_layer_get_auto_transition (layer2));
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -300,6 +313,8 @@ GST_START_TEST (test_single_layer_automatic_transition)
   GESLayer *layer;
   GESTimelineElement *src, *src1, *src2;
 
+  ges_init ();
+
   asset = ges_asset_request (GES_TYPE_TEST_CLIP, NULL, NULL);
   fail_unless (GES_IS_ASSET (asset));
 
@@ -681,6 +696,8 @@ GST_START_TEST (test_single_layer_automatic_transition)
   g_list_free_full (objects, gst_object_unref);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -694,6 +711,8 @@ GST_START_TEST (test_multi_layer_automatic_transition)
   GESLayer *layer, *layer1;
   GESTimelineElement *src, *src1, *src2, *src3;
 
+  ges_init ();
+
   asset = ges_asset_request (GES_TYPE_TEST_CLIP, NULL, NULL);
   fail_unless (GES_IS_ASSET (asset));
 
@@ -1168,6 +1187,8 @@ GST_START_TEST (test_multi_layer_automatic_transition)
   ASSERT_OBJECT_REFCOUNT (transition, "layer + timeline", 2);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1181,6 +1202,8 @@ GST_START_TEST (test_layer_activate_automatic_transition)
   GESClip *transition;
   GESTimelineElement *src, *src1, *src2, *src3;
 
+  ges_init ();
+
   asset = ges_asset_request (GES_TYPE_TEST_CLIP, NULL, NULL);
   transition_asset =
       ges_asset_request (GES_TYPE_TRANSITION_CLIP, "crossfade", NULL);
@@ -1397,6 +1420,8 @@ GST_START_TEST (test_layer_activate_automatic_transition)
 
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1407,6 +1432,8 @@ GST_START_TEST (test_layer_meta_string)
   GESLayer *layer;
   const gchar *result;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1418,6 +1445,8 @@ GST_START_TEST (test_layer_meta_string)
               (layer), "ges-test")) != NULL);
 
   assert_equals_string (result, "blub");
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1428,6 +1457,8 @@ GST_START_TEST (test_layer_meta_boolean)
   GESLayer *layer;
   gboolean result;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1438,6 +1469,8 @@ GST_START_TEST (test_layer_meta_boolean)
           (layer), "ges-test", &result));
 
   fail_unless (result);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1448,6 +1481,8 @@ GST_START_TEST (test_layer_meta_int)
   GESLayer *layer;
   gint result;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1458,6 +1493,8 @@ GST_START_TEST (test_layer_meta_int)
           "ges-test", &result));
 
   assert_equals_int (result, 1234);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1468,6 +1505,8 @@ GST_START_TEST (test_layer_meta_uint)
   GESLayer *layer;
   guint result;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1478,6 +1517,8 @@ GST_START_TEST (test_layer_meta_uint)
           (layer), "ges-test", &result));
 
   assert_equals_int (result, 42);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1488,6 +1529,8 @@ GST_START_TEST (test_layer_meta_int64)
   GESLayer *layer;
   gint64 result;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1498,6 +1541,8 @@ GST_START_TEST (test_layer_meta_int64)
           "ges-test", &result));
 
   assert_equals_int64 (result, 1234);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1508,6 +1553,8 @@ GST_START_TEST (test_layer_meta_uint64)
   GESLayer *layer;
   guint64 result;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1518,6 +1565,8 @@ GST_START_TEST (test_layer_meta_uint64)
           (layer), "ges-test", &result));
 
   assert_equals_uint64 (result, 42);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1528,6 +1577,8 @@ GST_START_TEST (test_layer_meta_float)
   GESLayer *layer;
   gfloat result;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1539,6 +1590,8 @@ GST_START_TEST (test_layer_meta_float)
           "ges-test", &result));
 
   assert_equals_float (result, 23.456f);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1549,6 +1602,8 @@ GST_START_TEST (test_layer_meta_double)
   GESLayer *layer;
   gdouble result;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1562,6 +1617,8 @@ GST_START_TEST (test_layer_meta_double)
 
   //TODO CHECK
   assert_equals_float (result, 23.456);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1573,6 +1630,8 @@ GST_START_TEST (test_layer_meta_date)
   GDate *input;
   GDate *result;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1588,6 +1647,8 @@ GST_START_TEST (test_layer_meta_date)
 
   g_date_free (input);
   g_date_free (result);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1599,6 +1660,8 @@ GST_START_TEST (test_layer_meta_date_time)
   GstDateTime *input;
   GstDateTime *result = NULL;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1618,6 +1681,8 @@ GST_START_TEST (test_layer_meta_date_time)
 
   gst_date_time_unref (input);
   gst_date_time_unref (result);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1630,6 +1695,8 @@ GST_START_TEST (test_layer_meta_value)
   GValue data = G_VALUE_INIT;
   const GValue *result;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1646,6 +1713,8 @@ GST_START_TEST (test_layer_meta_value)
   assert_equals_string (g_value_get_string (result), "Hello world!");
 
   g_value_unset (&data);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1656,6 +1725,8 @@ GST_START_TEST (test_layer_meta_register)
   GESLayer *layer;
   const gchar *result;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1673,6 +1744,8 @@ GST_START_TEST (test_layer_meta_register)
   result = ges_meta_container_get_string (GES_META_CONTAINER (layer),
       "ges-test-value");
   assert_equals_string (result, "Hello world!");
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1690,6 +1763,8 @@ GST_START_TEST (test_layer_meta_foreach)
   GESTimeline *timeline;
   GESLayer *layer;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1701,6 +1776,8 @@ GST_START_TEST (test_layer_meta_foreach)
 
   ges_meta_container_foreach (GES_META_CONTAINER (layer),
       (GESMetaForeachFunc) test_foreach, NULL);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1712,6 +1789,8 @@ GST_START_TEST (test_layer_get_clips_in_interval)
   GESClip *clip, *clip2, *clip3;
   GList *objects, *current;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   layer = ges_layer_new ();
   ges_timeline_add_layer (timeline, layer);
@@ -1815,6 +1894,7 @@ GST_START_TEST (test_layer_get_clips_in_interval)
   fail_unless (current->data == GES_TIMELINE_ELEMENT (clip2));
   g_list_free_full (objects, gst_object_unref);
 
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1825,12 +1905,6 @@ ges_suite (void)
   Suite *s = suite_create ("ges-layer");
   TCase *tc_chain = tcase_create ("timeline-layer");
 
-  ges_init ();
-
-  if (atexit (ges_deinit) != 0) {
-    GST_ERROR ("failed to set ges_deinit as exit function");
-  }
-
   suite_add_tcase (s, tc_chain);
 
   tcase_add_test (tc_chain, test_layer_properties);
