@@ -47,6 +47,8 @@ GST_START_TEST (test_basic_timeline_edition)
   GESTrackElement *trackelement, *trackelement1, *trackelement2;
   GESContainer *clip, *clip1, *clip2;
 
+  ges_init ();
+
   track = GES_TRACK (ges_audio_track_new ());
   fail_unless (track != NULL);
 
@@ -230,6 +232,8 @@ GST_START_TEST (test_basic_timeline_edition)
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -243,6 +247,8 @@ GST_START_TEST (test_snapping)
   GESLayer *layer;
   GList *trackelements;
 
+  ges_init ();
+
   track = GES_TRACK (ges_video_track_new ());
   fail_unless (track != NULL);
 
@@ -474,6 +480,8 @@ GST_START_TEST (test_snapping)
 
   check_destroyed (G_OBJECT (timeline), G_OBJECT (trackelement),
       trackelement1, trackelement2, clip, clip1, clip2, layer, NULL);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -498,8 +506,11 @@ GST_START_TEST (test_simple_triming)
   GESTimeline *timeline;
   GESLayer *layer;
   GESTimelineElement *element;
+  gchar *uri;
 
-  gchar *uri = ges_test_file_uri ("audio_video.ogg");
+  ges_init ();
+
+  uri = ges_test_file_uri ("audio_video.ogg");
 
   project = ges_project_new (NULL);
 
@@ -535,6 +546,8 @@ GST_START_TEST (test_simple_triming)
   g_main_loop_unref (mainloop);
   gst_object_unref (timeline);
   gst_object_unref (project);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -548,6 +561,8 @@ GST_START_TEST (test_timeline_edition_mode)
   GESLayer *layer, *layer1, *layer2;
   GList *trackelements, *layers, *tmp;
 
+  ges_init ();
+
   track = GES_TRACK (ges_video_track_new ());
   fail_unless (track != NULL);
 
@@ -969,6 +984,7 @@ GST_START_TEST (test_timeline_edition_mode)
   CHECK_OBJECT_PROPS (trackelement1, 25, 5, 37);
   CHECK_OBJECT_PROPS (trackelement2, 62, 0, 60);
 
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -983,6 +999,8 @@ GST_START_TEST (test_groups)
 
   GList *clips = NULL;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
 
   /* Our timeline
@@ -1024,18 +1042,18 @@ GST_START_TEST (test_groups)
   g_list_free (clips);
 
   fail_unless (GES_IS_GROUP (group));
-  CHECK_OBJECT_PROPS (c, 0, 0, 10);
-  CHECK_OBJECT_PROPS (c1, 10, 0, 10);
-  CHECK_OBJECT_PROPS (c2, 20, 0, 10);
+  DEEP_CHECK (c, 0, 0, 10);
+  DEEP_CHECK (c1, 10, 0, 10);
+  DEEP_CHECK (c2, 20, 0, 10);
   CHECK_OBJECT_PROPS (group, 0, 0, 30);
 
   c3 = ges_layer_add_asset (layer, asset, 30, 0, 20, GES_TRACK_TYPE_UNKNOWN);
   c4 = ges_layer_add_asset (layer1, asset, 40, 0, 20, GES_TRACK_TYPE_UNKNOWN);
   c5 = ges_layer_add_asset (layer2, asset, 50, 0, 20, GES_TRACK_TYPE_UNKNOWN);
 
-  CHECK_OBJECT_PROPS (c3, 30, 0, 20);
-  CHECK_OBJECT_PROPS (c4, 40, 0, 20);
-  CHECK_OBJECT_PROPS (c5, 50, 0, 20);
+  DEEP_CHECK (c3, 30, 0, 20);
+  DEEP_CHECK (c4, 40, 0, 20);
+  DEEP_CHECK (c5, 50, 0, 20);
   check_layer (c, 0);
   check_layer (c1, 1);
   check_layer (c2, 1);
@@ -1046,12 +1064,12 @@ GST_START_TEST (test_groups)
   fail_unless (ges_container_edit (GES_CONTAINER (c), NULL, -1,
           GES_EDIT_MODE_RIPPLE, GES_EDGE_NONE, 10) == TRUE);
 
-  CHECK_OBJECT_PROPS (c, 10, 0, 10);
-  CHECK_OBJECT_PROPS (c1, 20, 0, 10);
-  CHECK_OBJECT_PROPS (c2, 30, 0, 10);
-  CHECK_OBJECT_PROPS (c3, 40, 0, 20);
-  CHECK_OBJECT_PROPS (c4, 50, 0, 20);
-  CHECK_OBJECT_PROPS (c5, 60, 0, 20);
+  DEEP_CHECK (c, 10, 0, 10);
+  DEEP_CHECK (c1, 20, 0, 10);
+  DEEP_CHECK (c2, 30, 0, 10);
+  DEEP_CHECK (c3, 40, 0, 20);
+  DEEP_CHECK (c4, 50, 0, 20);
+  DEEP_CHECK (c5, 60, 0, 20);
   check_layer (c, 0);
   check_layer (c1, 1);
   check_layer (c2, 1);
@@ -1061,12 +1079,12 @@ GST_START_TEST (test_groups)
 
   fail_unless (ges_container_edit (GES_CONTAINER (c), NULL, 1,
           GES_EDIT_MODE_RIPPLE, GES_EDGE_NONE, 10) == TRUE);
-  CHECK_OBJECT_PROPS (c, 10, 0, 10);
-  CHECK_OBJECT_PROPS (c1, 20, 0, 10);
-  CHECK_OBJECT_PROPS (c2, 30, 0, 10);
-  CHECK_OBJECT_PROPS (c3, 40, 0, 20);
-  CHECK_OBJECT_PROPS (c4, 50, 0, 20);
-  CHECK_OBJECT_PROPS (c5, 60, 0, 20);
+  DEEP_CHECK (c, 10, 0, 10);
+  DEEP_CHECK (c1, 20, 0, 10);
+  DEEP_CHECK (c2, 30, 0, 10);
+  DEEP_CHECK (c3, 40, 0, 20);
+  DEEP_CHECK (c4, 50, 0, 20);
+  DEEP_CHECK (c5, 60, 0, 20);
   check_layer (c, 1);
   check_layer (c1, 2);
   check_layer (c2, 2);
@@ -1076,12 +1094,12 @@ GST_START_TEST (test_groups)
 
   fail_unless (ges_container_edit (GES_CONTAINER (c1), NULL, 2,
           GES_EDIT_MODE_RIPPLE, GES_EDGE_END, 40) == TRUE);
-  CHECK_OBJECT_PROPS (c, 10, 0, 10);
-  CHECK_OBJECT_PROPS (c1, 20, 0, 20);
-  CHECK_OBJECT_PROPS (c2, 40, 0, 10);
-  CHECK_OBJECT_PROPS (c3, 50, 0, 20);
-  CHECK_OBJECT_PROPS (c4, 60, 0, 20);
-  CHECK_OBJECT_PROPS (c5, 70, 0, 20);
+  DEEP_CHECK (c, 10, 0, 10);
+  DEEP_CHECK (c1, 20, 0, 20);
+  DEEP_CHECK (c2, 40, 0, 10);
+  DEEP_CHECK (c3, 50, 0, 20);
+  DEEP_CHECK (c4, 60, 0, 20);
+  DEEP_CHECK (c5, 70, 0, 20);
   check_layer (c, 1);
   check_layer (c1, 2);
   check_layer (c2, 2);
@@ -1091,12 +1109,12 @@ GST_START_TEST (test_groups)
 
   fail_unless (ges_container_edit (GES_CONTAINER (c1), NULL, 2,
           GES_EDIT_MODE_RIPPLE, GES_EDGE_END, 30) == TRUE);
-  CHECK_OBJECT_PROPS (c, 10, 0, 10);
-  CHECK_OBJECT_PROPS (c1, 20, 0, 10);
-  CHECK_OBJECT_PROPS (c2, 30, 0, 10);
-  CHECK_OBJECT_PROPS (c3, 40, 0, 20);
-  CHECK_OBJECT_PROPS (c4, 50, 0, 20);
-  CHECK_OBJECT_PROPS (c5, 60, 0, 20);
+  DEEP_CHECK (c, 10, 0, 10);
+  DEEP_CHECK (c1, 20, 0, 10);
+  DEEP_CHECK (c2, 30, 0, 10);
+  DEEP_CHECK (c3, 40, 0, 20);
+  DEEP_CHECK (c4, 50, 0, 20);
+  DEEP_CHECK (c5, 60, 0, 20);
   check_layer (c, 1);
   check_layer (c1, 2);
   check_layer (c2, 2);
@@ -1106,12 +1124,12 @@ GST_START_TEST (test_groups)
 
   fail_unless (ges_container_edit (GES_CONTAINER (c), NULL, 0,
           GES_EDIT_MODE_RIPPLE, GES_EDGE_NONE, 0) == TRUE);
-  CHECK_OBJECT_PROPS (c, 0, 0, 10);
-  CHECK_OBJECT_PROPS (c1, 10, 0, 10);
-  CHECK_OBJECT_PROPS (c2, 20, 0, 10);
-  CHECK_OBJECT_PROPS (c3, 30, 0, 20);
-  CHECK_OBJECT_PROPS (c4, 40, 0, 20);
-  CHECK_OBJECT_PROPS (c5, 50, 0, 20);
+  DEEP_CHECK (c, 0, 0, 10);
+  DEEP_CHECK (c1, 10, 0, 10);
+  DEEP_CHECK (c2, 20, 0, 10);
+  DEEP_CHECK (c3, 30, 0, 20);
+  DEEP_CHECK (c4, 40, 0, 20);
+  DEEP_CHECK (c5, 50, 0, 20);
   check_layer (c, 0);
   check_layer (c1, 1);
   check_layer (c2, 1);
@@ -1121,12 +1139,12 @@ GST_START_TEST (test_groups)
 
   fail_unless (ges_container_edit (GES_CONTAINER (c2), NULL, -1,
           GES_EDIT_MODE_ROLL, GES_EDGE_END, 40) == TRUE);
-  CHECK_OBJECT_PROPS (c, 0, 0, 10);
-  CHECK_OBJECT_PROPS (c1, 10, 0, 10);
-  CHECK_OBJECT_PROPS (c2, 20, 0, 20);
-  CHECK_OBJECT_PROPS (c3, 40, 10, 10);
-  CHECK_OBJECT_PROPS (c4, 40, 0, 20);
-  CHECK_OBJECT_PROPS (c5, 50, 0, 20);
+  DEEP_CHECK (c, 0, 0, 10);
+  DEEP_CHECK (c1, 10, 0, 10);
+  DEEP_CHECK (c2, 20, 0, 20);
+  DEEP_CHECK (c3, 40, 10, 10);
+  DEEP_CHECK (c4, 40, 0, 20);
+  DEEP_CHECK (c5, 50, 0, 20);
   CHECK_OBJECT_PROPS (group, 0, 0, 40);
   check_layer (c, 0);
   check_layer (c1, 1);
@@ -1153,6 +1171,8 @@ GST_START_TEST (test_groups)
 
   gst_object_unref (timeline);
   gst_object_unref (asset);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1167,6 +1187,8 @@ GST_START_TEST (test_snapping_groups)
 
   GList *clips = NULL;
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   g_object_set (timeline, "snapping-distance", (guint64) 3, NULL);
 
@@ -1249,6 +1271,8 @@ GST_START_TEST (test_snapping_groups)
 
   gst_object_unref (timeline);
   gst_object_unref (asset);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1307,8 +1331,13 @@ GST_START_TEST (test_scaling)
   GESLayer *layer;
   GESAsset *asset1, *asset2;
   GESClip *clip;
-  GESTrack *trackv = GES_TRACK (ges_video_track_new ());
-  GstCaps *caps =
+  GESTrack *trackv;
+  GstCaps *caps;
+
+  ges_init ();
+
+  trackv = GES_TRACK (ges_video_track_new ());
+  caps =
       gst_caps_new_simple ("video/x-raw", "width", G_TYPE_INT, 1200, "height",
       G_TYPE_INT, 1000, NULL);
 
@@ -1491,6 +1520,8 @@ GST_START_TEST (test_scaling)
   fail_unless (check_frame_positioner_size (clip, 320, 240));
 
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -1501,8 +1532,6 @@ ges_suite (void)
   Suite *s = suite_create ("ges-timeline-edition");
   TCase *tc_chain = tcase_create ("timeline-edition");
 
-  ges_init ();
-
   suite_add_tcase (s, tc_chain);
 
   tcase_add_test (tc_chain, test_basic_timeline_edition);
