@@ -31,6 +31,8 @@ GST_START_TEST (test_title_source_basic)
   fail_unless (source != NULL);
 
   gst_object_unref (source);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -101,6 +103,8 @@ GST_START_TEST (test_title_source_properties)
   ges_container_remove (GES_CONTAINER (clip),
       GES_TIMELINE_ELEMENT (trackelement));
   gst_object_unref (clip);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -201,6 +205,8 @@ GST_START_TEST (test_title_source_in_layer)
 
   gst_object_unref (track_element);
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -211,10 +217,6 @@ ges_suite (void)
   Suite *s = suite_create ("ges-titles");
   TCase *tc_chain = tcase_create ("titles");
 
-  if (atexit (ges_deinit) != 0) {
-    GST_ERROR ("failed to set ges_deinit as exit function");
-  }
-
   suite_add_tcase (s, tc_chain);
 
   tcase_add_test (tc_chain, test_title_source_basic);
