@@ -86,6 +86,8 @@ GST_START_TEST (test_filesource_basic)
 
   mainloop = g_main_loop_new (NULL, FALSE);
 
+  ges_init ();
+
   timeline = ges_timeline_new_audio_video ();
   fail_unless (timeline != NULL);
 
@@ -99,6 +101,8 @@ GST_START_TEST (test_filesource_basic)
   g_main_loop_run (mainloop);
   g_main_loop_unref (mainloop);
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -123,6 +127,8 @@ GST_START_TEST (test_filesource_properties)
   GESLayer *layer;
   GESTrackElement *trackelement;
 
+  ges_init ();
+
   track = ges_track_new (GES_TRACK_TYPE_AUDIO, gst_caps_ref (GST_CAPS_ANY));
   fail_unless (track != NULL);
 
@@ -194,7 +200,10 @@ GST_START_TEST (test_filesource_properties)
   ges_container_remove (GES_CONTAINER (clip),
       GES_TIMELINE_ELEMENT (trackelement));
 
+  gst_object_unref (asset);
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -210,6 +219,8 @@ GST_START_TEST (test_filesource_images)
   GESLayer *layer;
   GESTrackElement *track_element;
 
+  ges_init ();
+
   a = GES_TRACK (ges_audio_track_new ());
   v = GES_TRACK (ges_video_track_new ());
 
@@ -254,7 +265,10 @@ GST_START_TEST (test_filesource_images)
   ASSERT_OBJECT_REFCOUNT (track_element, "1 in track, 1 in clip 2 in timeline",
       4);
 
+  gst_object_unref (asset);
   gst_object_unref (timeline);
+
+  ges_deinit ();
 }
 
 GST_END_TEST;
@@ -284,12 +298,6 @@ main (int argc, char **argv)
 
   gst_check_init (&argc, &argv);
 
-  ges_init ();
-
-  if (atexit (ges_deinit) != 0) {
-    GST_ERROR ("failed to set ges_deinit as exit function");
-  }
-
   s = ges_suite ();
 
   av_uri = ges_test_get_audio_video_uri ();
